from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ArtdLocationConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "artd_location"
    verbose_name = _("ARTD Location")
